Class: Railsmdb::CryptShared::Listing Private
- Inherits:
-
Object
- Object
- Railsmdb::CryptShared::Listing
- Defined in:
- lib/railsmdb/crypt_shared/listing.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
A utility class for fetching the JSON list of current MongoDB database offerings.
Class Method Summary collapse
-
.fetch ⇒ Hash
private
Convenience method for fetching and returning the current listing.
Instance Method Summary collapse
-
#listing ⇒ Hash
private
Downloads and parses the listing, returning the result.
Class Method Details
.fetch ⇒ Hash
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Convenience method for fetching and returning the current listing.
17 18 19 |
# File 'lib/railsmdb/crypt_shared/listing.rb', line 17 def self.fetch new.listing end |
Instance Method Details
#listing ⇒ Hash
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Downloads and parses the listing, returning the result.
24 25 26 |
# File 'lib/railsmdb/crypt_shared/listing.rb', line 24 def listing @listing ||= fetch_listing_json end |