Module: Railsmdb::Prioritizable

Extended by:
ActiveSupport::Concern
Included in:
Generators::Setup::Concerns::Setuppable
Defined in:
lib/railsmdb/prioritizable.rb

Overview

Defines the behavior for extending the Thor framework to allow commands to be reprioritized–ensuring they run immediately before or after another command.